==> 1.0.9-dev.tar.gz: lib/src/navigation/route_activity.dart <==
part of 'app_route.dart';

/// Activity route builder
typedef ActivityRouteBuilder = Route Function(RouteSettings settings);

/// [AppRoute] of an Activity
class ActivityRoute<T> extends AppRoute<T> {
  final ActivityRouteBuilder builder;

  ActivityRoute(String name, {RouteAccessibility? accessibility, required this.builder})
      : super(name, accessibility: accessibility);

  ActivityRoute.builder(
    Object name, {
    RouteAccessibility? accessibility,
    required RouteWidgetBuilder builder,
    ThemeBuilder? theme,
    SystemUiStyleBuilder systemUiStyle = Application.defaultSystemUiStyle,
    bool maintainState = true,
    bool fullscreenDialog = false,
  }) : this(AppRoute._routeName(name),
            accessibility: accessibility,
            builder: (settings) => MaterialPageRoute(
                builder: wrapIfNotNull<WidgetBuilder, ThemeBuilder>(
                    item: theme,
                    wrap: (child, theme) =>
                        (context) => Theme(data: theme(context, settings), child: Builder(builder: child)),
                    child: (context) => AnnotatedSystemUIStyle(
                        style: systemUiStyle(context), child: builder(context, settings.arguments as RouteArgs))),
                settings: settings,
                maintainState: maintainState,
                fullscreenDialog: fullscreenDialog));

  @override
  Future<T> open(BuildContext context, {RouteArgs args = const {}}) {
    final raw = Navigator.of(context).pushNamed(name, arguments: args);
    return AppRoute._result(raw);
  }

  @override
  Future<T> openReplace(BuildContext context, {RouteArgs args = const {}, Object? result}) {
    final raw = Navigator.of(context).pushReplacementNamed(name, arguments: args, result: result);
    return AppRoute._result(raw);
  }
}

==> 1.1.4-dev.tar.gz: lib/src/navigation/route_activity.dart <==
part of 'app_route.dart';

/// Activity route builder
typedef ActivityRouteBuilder = Route Function(RouteSettings settings);

/// [AppRoute] of an Activity
class ActivityRoute<T> extends AppRoute<T> {
  final ActivityRouteBuilder builder;

  ActivityRoute(String name, {RouteAccessibility? accessibility, required this.builder})
      : super(name, accessibility: accessibility);

  ActivityRoute.builder(
    Object name, {
    RouteAccessibility? accessibility,
    required RouteWidgetBuilder builder,
    ThemeBuilder? theme,
    SystemUiStyleBuilder systemUiStyle = Application.defaultSystemUiStyle,
    bool maintainState = true,
    bool fullscreenDialog = false,
  }) : this(AppRoute._routeName(name),
            accessibility: accessibility,
            builder: (settings) => MaterialPageRoute(
                builder: wrapIfNotNull<WidgetBuilder, ThemeBuilder>(
                    item: theme,
                    wrap: (child, theme) =>
                        (context) => Theme(data: theme(context, settings), child: Builder(builder: child)),
                    child: (context) => AnnotatedSystemUIStyle(
                        style: systemUiStyle(context), child: builder(context, settings.arguments as RouteArgs))),
                settings: settings,
                maintainState: maintainState,
                fullscreenDialog: fullscreenDialog));

  @override
  Future<T> open(BuildContext context, {RouteArgs args = const {}}) {
    final raw = Navigator.of(context).pushNamed(name, arguments: args);
    return AppRoute._result<T>(raw);
  }

  @override
  Future<T> openReplace(BuildContext context, {RouteArgs args = const {}, Object? result}) {
    final raw = Navigator.of(context).pushReplacementNamed(name, arguments: args, result: result);
    return AppRoute._result<T>(raw);
  }
}
